#ifndef __AVERAGEANDERROR_HH__
#define __AVERAGEANDERROR_HH__

#include<cmath>
#include<vector>

/// micro class to calculate averages and errors
class AverageAndError {
public:

  /// default constructor
  AverageAndError() { _sum = 0.0; _sum2 = 0.0; _n=0;}
  
  /// add one event
  inline void add(double x)  { _sum += x, 
                               _sum2 += x*x;
       		        _n += 1;
       		      }

  /// add vector with events
  inline void add(std::vector<double> v)  { 
      for(unsigned i=0;i<v.size();i++) add(v[i]);
  }

  /// add one event with a different notation
  inline void operator+= (double x) { add(x); }

  /// return sum
  inline double sum() const { return _sum; }

  /// return sum2
  inline double sum2() const { return _sum2; }
  
  /// return number of events
  inline int n() const { return _n; }
  
  /// allow the user to reset the effective value of n
  inline void set_n(int n_in) { _n = n_in;}

  /// calculate and return average
  inline double average() const { return (_n > 0) ? _sum/_n : 0. ; }

  /// calculate and return average of squares
  inline double average2() const { return (_n > 0) ? _sum2/_n : 0. ; }

  /// calculate and return error
  inline double error() const { return sd()/sqrt(_n); }

  /// return the error on the sum (as opposed to the error on the average)
  inline double error_on_sum() { return error() * n(); }

  /// calculate and return the standard deviation (i.e. sqrt of the unbiased sample variance)
  inline double sd() const { return (_n > 1) ? std::sqrt(std::abs(_sum2 - _sum*_sum/_n)/(_n-1)) : 0.; }
   
private:

double _sum, _sum2;
int _n;

};

#endif // __AVERAGEANDERROR_HH__
